@@ -51,6 +51,7 @@ def main():
   parser.add_option("-o", "--org", dest="org", help="Github.com organization name. Assumes Oauth user if omitted.")
   parser.add_option("-u", "--user", dest="user", help="Github.com user name. Assumes Oauth user if omitted.")
   parser.add_option("-a", "--a", dest="access_token", help="OAuth Access Token.")
+  parser.add_option("-d", "--depth", dest="depth", help="Git clone depth.")
   parser.add_option("-t", "--type", dest="type",  help="Type of repos to return. Org: all, public, private, forks, sources, member. User: all, owner, member. With Token: all, owner, public, private, member. Default is all.")
   parser.add_option("-r", "--run", action="store_true", dest="run", default=False,  help="Execute changes. Default is Dry Run.")
   parser.add_option("-v", "--verbose", action="store_true", dest="verbose", default=False,  help="Verbose logging - includes URL calls and API JSON responses.")
@@ -68,10 +69,15 @@ def main():
       print 'Page: {} Count: {}'.format(page, len(data))
       print ''
       for o in data:
+        cmd = 'git clone'
+        if options.depth:
+          cmd = '{} --depth {}'.format(cmd, options.depth)
+        cmd = '{} {}'.format(cmd, o['clone_url'])
+
         if options.run == False:
-          print o['clone_url']
+          print cmd
         else:
-          os.system('git clone {}'.format(o['clone_url']))
+          os.system(cmd)
 
       page += 1
       data = call_api(options, url, page)
